::: ropt.plugins.function_transform

::: ropt.plugins.function_transform.protocol

::: ropt.plugins.function_transform.default
    options:
        members: none

::: ropt.plugins.function_transform.default.DefaultFunctionTransform
    options:
        members: none
